@@ -25,7 +25,6 @@
  * HUBzero is a registered trademark of Purdue University.
  *
  * @package   hubzero-cms
- * @author    Alissa Nedossekina <alisa@purdue.edu>
  * @copyright Copyright 2005-2015 HUBzero Foundation, LLC.
  * @license   http://opensource.org/licenses/MIT MIT
  */
@@ -34,13 +33,11 @@ namespace Components\Answers\Admin\Controllers;
 
 use Hubzero\Component\AdminController;
 use Components\Answers\Models\Question;
-use Components\Answers\Tables;
-use Exception;
 use Request;
-use Config;
 use Notify;
 use Route;
 use Lang;
+use User;
 use App;
 
 /**
@@ -73,37 +70,24 @@ class Questions extends AdminController
 	public function displayTask()
 	{
 		// Filters
-		$this->view->filters = array(
+		$filters = array(
 			'tag' => Request::getstate(
 				$this->_option . '.' . $this->_controller . '.tag',
 				'tag',
 				''
 			),
-			'q' => Request::getstate(
-				$this->_option . '.' . $this->_controller . '.q',
-				'q',
+			'search' => Request::getState(
+				$this->_option . '.' . $this->_controller . '.search',
+				'search',
 				''
 			),
-			'filterby' => Request::getstate(
-				$this->_option . '.' . $this->_controller . '.filterby',
-				'filterby',
-				'all'
-			),
-			// Paging
-			'limit' => Request::getstate(
-				$this->_option . '.' . $this->_controller . '.limit',
-				'limit',
-				Config::get('list_limit'),
-				'int'
-			),
-			'start' => Request::getstate(
-				$this->_option . '.' . $this->_controller . '.limitstart',
-				'limitstart',
-				0,
+			'state' => Request::getstate(
+				$this->_option . '.' . $this->_controller . '.state',
+				'state',
+				-1,
 				'int'
 			),
 			// Sorting
-			'sortby' => '',
 			'sort' => Request::getstate(
 				$this->_option . '.' . $this->_controller . '.sort',
 				'filter_order',
@@ -116,25 +100,40 @@ class Questions extends AdminController
 			)
 		);
 
-		$aq = new Tables\Question($this->database);
+		$records = Question::all()
+			->including(['creator', function ($creator){
+				$creator->select('*');
+			}])
+			->including(['responses', function ($response){
+				$response
+					->select('id')
+					->select('question_id');
+			}]);
 
-		// Get a record count
-		$this->view->total = $aq->getCount($this->view->filters);
-
-		// Get records
-		$this->view->results = $aq->getResults($this->view->filters);
-
-		// Did we get any results?
-		if ($this->view->results)
+		if ($filters['search'])
 		{
-			foreach ($this->view->results as $key => $result)
-			{
-				$this->view->results[$key] = new Question($result);
-			}
+			$filters['search'] = strtolower((string)$filters['search']);
+
+			$records->whereLike('subject', $filters['search'], 1)
+					->orWhereLike('question', $filters['search'], 1)
+					->resetDepth();
 		}
 
+		if ($filters['state'] >= 0)
+		{
+			$records->whereEquals('state', $filters['state']);
+		}
+
+		$rows = $records
+			->ordered('filter_order', 'filter_order_Dir')
+			->paginated('limitstart', 'limit')
+			->rows();
+
 		// Output the HTML
-		$this->view->display();
+		$this->view
+			->set('rows', $rows)
+			->set('filters', $filters)
+			->display();
 	}
 
 	/**
@@ -145,6 +144,12 @@ class Questions extends AdminController
 	 */
 	public function editTask($row=null)
 	{
+		if (!User::authorise('core.edit', $this->_option)
+		 && !User::authorise('core.create', $this->_option))
+		{
+			App::abort(403, Lang::txt('JERROR_ALERTNOAUTHOR'));
+		}
+
 		Request::setVar('hidemainmenu', 1);
 
 		// Load object
@@ -154,7 +159,7 @@ class Questions extends AdminController
 			$id = Request::getVar('id', array(0));
 			$id = is_array($id) ? $id[0] : $id;
 
-			$row = new Question($id);
+			$row = Question::oneOrNew($id);
 		}
 
 		// Output the HTML
@@ -174,20 +179,26 @@ class Questions extends AdminController
 		// Check for request forgeries
 		Request::checkToken();
 
-		// Incoming data
-		$fields = Request::getVar('question', array(), 'post', 'none', 2);
-
-		// Initiate model
-		$row = new Question($fields['id']);
-
-		if (!$row->bind($fields))
+		if (!User::authorise('core.edit', $this->_option)
+		 && !User::authorise('core.create', $this->_option))
 		{
-			Notify::error($row->getError());
-			return $this->editTask($row);
+			App::abort(403, Lang::txt('JERROR_ALERTNOAUTHOR'));
 		}
 
+		// Incoming data
+		$fields = Request::getVar('question', array(), 'post', 'none', 2);
+		$tags = null;
+		if (isset($fields['tags']))
+		{
+			$tags = $fields['tags'];
+			unset($fields['tags']);
+		}
+
+		// Initiate model
+		$row = Question::oneOrNew($fields['id'])->set($fields);
+
 		// Ensure we have at least one tag
-		if (!isset($fields['tags']) || !$fields['tags'])
+		if (!$tags)
 		{
 			Notify::error(Lang::txt('COM_ANSWERS_ERROR_QUESTION_MUST_HAVE_TAGS'));
 			return $this->editTask($row);
@@ -197,14 +208,14 @@ class Questions extends AdminController
 		$row->set('anonymous', (isset($fields['anonymous']) ? 1 : 0));
 
 		// Store content
-		if (!$row->store(true))
+		if (!$row->save())
 		{
 			Notify::error($row->getError());
 			return $this->editTask($row);
 		}
 
 		// Add the tag(s)
-		$row->tag($fields['tags'], User::get('id'));
+		$row->tag($tags, User::get('id'));
 
 		Notify::success(Lang::txt('COM_ANSWERS_QUESTION_SAVED'));
 
@@ -214,9 +225,7 @@ class Questions extends AdminController
 		}
 
 		// Redirect back to the full questions list
-		App::redirect(
-			Route::url('index.php?option=' . $this->_option . '&controller=' . $this->_controller, false)
-		);
+		$this->cancelTask();
 	}
 
 	/**
@@ -229,45 +238,42 @@ class Questions extends AdminController
 		// Check for request forgeries
 		Request::checkToken();
 
+		if (!User::authorise('core.delete', $this->_option))
+		{
+			App::abort(403, Lang::txt('JERROR_ALERTNOAUTHOR'));
+		}
+
 		// Incoming
 		$ids = Request::getVar('id', array());
 		$ids = (!is_array($ids) ? array($ids) : $ids);
 
 		if (count($ids) <= 0)
 		{
-			App::redirect(
-				Route::url('index.php?option=' . $this->_option . '&controller=' . $this->_controller, false)
-			);
-			return;
+			return $this->cancelTask();
 		}
 
+		$i = 0;
 		foreach ($ids as $id)
 		{
 			// Load the record
-			$aq = new Question(intval($id));
+			$aq = Question::oneOrFail(intval($id));
 
 			// Delete the question
-			if (!$aq->delete())
+			if (!$aq->destroy())
 			{
-				$this->setError($aq->getError());
+				Notify::error($aq->getError());
+				continue;
 			}
+
+			$i++;
 		}
 
-		// Redirect
-		if ($this->getError())
+		if ($i)
 		{
-			App::redirect(
-				Route::url('index.php?option=' . $this->_option . '&controller=' . $this->_controller, false),
-				implode('<br />', $this->getErrors()),
-				'error'
-			);
-			return;
+			Notify::success(Lang::txt('COM_ANSWERS_QUESTION_DELETED'));
 		}
 
-		App::redirect(
-			Route::url('index.php?option=' . $this->_option . '&controller=' . $this->_controller, false),
-			Lang::txt('COM_ANSWERS_QUESTION_DELETED')
-		);
+		$this->cancelTask();
 	}
 
 	/**
@@ -280,59 +286,58 @@ class Questions extends AdminController
 		// Check for request forgeries
 		Request::checkToken(['get', 'post']);
 
+		if (!User::authorise('core.edit.state', $this->_option))
+		{
+			App::abort(403, Lang::txt('JERROR_ALERTNOAUTHOR'));
+		}
+
 		// Incoming
 		$ids = Request::getVar('id', array());
 		$ids = (!is_array($ids) ? array($ids) : $ids);
 
-		$publish = ($this->getTask() == 'close') ? 1 : 0;
+		$publish = ($this->_task == 'close') ? 1 : 0;
 
 		// Check for an ID
 		if (count($ids) < 1)
 		{
 			$action = ($publish == 1) ? Lang::txt('COM_ANSWERS_SET_STATE_CLOSE') : Lang::txt('COM_ANSWERS_SET_STATE_OPEN');
 
-			App::redirect(
-				Route::url('index.php?option=' . $this->_option . '&controller=' . $this->_controller, false),
-				Lang::txt('COM_ANSWERS_ERROR_SELECT_QUESTION_TO', $action),
-				'error'
-			);
-			return;
+			Notify::warning(Lang::txt('COM_ANSWERS_ERROR_SELECT_QUESTION_TO', $action));
+
+			return $this->cancelTask();
 		}
 
+		$i = 0;
 		foreach ($ids as $id)
 		{
 			// Update record(s)
-			$aq = new Question(intval($id));
-			if (!$aq->exists())
-			{
-				continue;
-			}
+			$aq = Question::oneOrFail(intval($id));
 			$aq->set('state', $publish);
 
-			if ($publish == 1)
+			if (!$aq->save())
 			{
-				$aq->adjustCredits();
+				Notify::error($aq->getError());
+				continue;
 			}
 
-			if (!$aq->store())
-			{
-				throw new Exception($aq->getError(), 500);
-			}
+			$i++;
 		}
 
 		// Set message
-		if ($publish == 1)
+		if ($i)
 		{
-			$message = Lang::txt('COM_ANSWERS_QUESTIONS_CLOSED', count($ids));
-		}
-		else if ($publish == 0)
-		{
-			$message = Lang::txt('COM_ANSWERS_QUESTIONS_OPENED', count($ids));
+			if ($publish == 1)
+			{
+				$message = Lang::txt('COM_ANSWERS_QUESTIONS_CLOSED', $i);
+			}
+			else if ($publish == 0)
+			{
+				$message = Lang::txt('COM_ANSWERS_QUESTIONS_OPENED', $i);
+			}
+
+			Notify::success($message);
 		}
 
-		App::redirect(
-			Route::url('index.php?option=' . $this->_option . '&controller=' . $this->_controller, false),
-			$message
-		);
+		$this->cancelTask();
 	}
 }
