@@ -42,4 +42,4 @@ if ($this->xprofile->get('orginization'))
 '<?php echo $this->xprofile->get('username'); ?>' on <?php echo $this->sitename; ?>.
 
 Click the following link to review this user's account:
-<?php echo $this->baseUrl . Route::url($this->xprofile->getLink()); ?>
\ No newline at end of file
+<?php echo $this->baseUrl . Route::url($this->xprofile->link()); ?>
\ No newline at end of file
